==> anjuta-3.1.92.tar.xz: anjuta-3.1.92/libanjuta/libanjuta.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * libanjuta.h
 * Copyright (C) Naba Kumar  <naba@gnome.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#ifndef LIBANJUTA_H
#define LIBANJUTA_H

/* FIXME: Update required */
#include <libanjuta/anjuta-debug.h>
#include <libanjuta/anjuta-encodings.h>
#include <libanjuta/anjuta-convert.h>
#include <libanjuta/anjuta-enum-types.h>
#include <libanjuta/anjuta-launcher.h>
#include <libanjuta/anjuta-marshal.h>
#include <libanjuta/anjuta-plugin-description.h>
#include <libanjuta/anjuta-plugin.h>
#include <libanjuta/anjuta-plugin-manager.h>
#include <libanjuta/anjuta-plugin-handle.h>
#include <libanjuta/anjuta-preferences-dialog.h>
#include <libanjuta/anjuta-preferences.h>
#include <libanjuta/anjuta-profile.h>
#include <libanjuta/anjuta-profile-manager.h>
#include <libanjuta/anjuta-save-prompt.h>
#include <libanjuta/anjuta-serializer.h>
#include <libanjuta/anjuta-session.h>
#include <libanjuta/anjuta-shell.h>
#include <libanjuta/anjuta-status.h>
#include <libanjuta/anjuta-ui.h>
#include <libanjuta/anjuta-utils.h>
#include <libanjuta/anjuta-version.h>
#include <libanjuta/resources.h>
#include <libanjuta/anjuta-vcs-status-tree-view.h>
#include <libanjuta/anjuta-command.h>
#include <libanjuta/anjuta-async-command.h>
#include <libanjuta/anjuta-async-notify.h>
#include <libanjuta/anjuta-sync-command.h>
#include <libanjuta/anjuta-project.h>
#include <libanjuta/anjuta-command-queue.h>
#include <libanjuta/anjuta-command-bar.h>
#include <libanjuta/anjuta-dock.h>
#include <libanjuta/anjuta-dock-pane.h>
#include <libanjuta/anjuta-token.h>

#endif

==> anjuta-3.18.2.tar.xz: anjuta-3.18.2/libanjuta/libanjuta.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * libanjuta.h
 * Copyright (C) Naba Kumar  <naba@gnome.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#ifndef LIBANJUTA_H
#define LIBANJUTA_H

/* FIXME: Update required */
#include <libanjuta/anjuta-debug.h>
#include <libanjuta/anjuta-encodings.h>
#include <libanjuta/anjuta-convert.h>
#include <libanjuta/anjuta-enum-types.h>
#include <libanjuta/anjuta-launcher.h>
#include <libanjuta/anjuta-marshal.h>
#include <libanjuta/anjuta-plugin-description.h>
#include <libanjuta/anjuta-plugin.h>
#include <libanjuta/anjuta-plugin-manager.h>
#include <libanjuta/anjuta-plugin-handle.h>
#include <libanjuta/anjuta-preferences-dialog.h>
#include <libanjuta/anjuta-preferences.h>
#include <libanjuta/anjuta-profile.h>
#include <libanjuta/anjuta-profile-manager.h>
#include <libanjuta/anjuta-save-prompt.h>
#include <libanjuta/anjuta-serializer.h>
#include <libanjuta/anjuta-session.h>
#include <libanjuta/anjuta-shell.h>
#include <libanjuta/anjuta-status.h>
#include <libanjuta/anjuta-ui.h>
#include <libanjuta/anjuta-utils.h>
#include <libanjuta/anjuta-version.h>
#include <libanjuta/resources.h>
#include <libanjuta/anjuta-vcs-status-tree-view.h>
#include <libanjuta/anjuta-command.h>
#include <libanjuta/anjuta-async-command.h>
#include <libanjuta/anjuta-async-notify.h>
#include <libanjuta/anjuta-sync-command.h>
#include <libanjuta/anjuta-project.h>
#include <libanjuta/anjuta-command-queue.h>
#include <libanjuta/anjuta-command-bar.h>
#include <libanjuta/anjuta-dock.h>
#include <libanjuta/anjuta-dock-pane.h>
#include <libanjuta/anjuta-token.h>
#include <libanjuta/anjuta-autogen.h>
#include <libanjuta/anjuta-cell-renderer-captioned-image.h>
#include <libanjuta/anjuta-column-text-view.h>
#include <libanjuta/anjuta-completion.h>
#include <libanjuta/anjuta-drop-entry.h>
#include <libanjuta/anjuta-entry.h>
#include <libanjuta/anjuta-environment-editor.h>
#include <libanjuta/anjuta-file-drop-entry.h>
#include <libanjuta/anjuta-file-list.h>
#include <libanjuta/anjuta-language-provider.h>
#include <libanjuta/anjuta-pkg-config.h>
#include <libanjuta/anjuta-pkg-config-chooser.h>
#include <libanjuta/anjuta-pkg-scanner.h>
#include <libanjuta/anjuta-tabber.h>
#include <libanjuta/anjuta-token-file.h>
#include <libanjuta/anjuta-token-list.h>
#include <libanjuta/anjuta-token-stream.h>
#include <libanjuta/anjuta-tree-combo.h>
#include <libanjuta/anjuta-vcs-status.h>
#include <libanjuta/anjuta-close-button.h>
#include <libanjuta/anjuta-modeline.h>

#endif
